#
# spec file for package d2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           d2
Version:        0.6.0
Release:        2.1
Summary:        CLI tool and modern declarative language that turns text to diagrams
License:        Apache-2.0 AND MIT AND MPL-2.0 AND EPL-2.0 AND GPL-2.0-or-later AND BSD-3-Clause
Group:          Productivity/Text/Utilities
URL:            https://github.com/terrastruct/d2
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.20

%description
A modern declarative diagramming language that turns text to diagrams. Create
beautiful diagrams in minutes. Simple syntax. Endlessly customizable. D2 is the
fastest and easiest way to get a mental model from your head onto the screen,
then make edits with your team.

%prep
%autosetup -a 1

%build
go build \
   -buildmode=pie

%check
# execute the binary as a basic check
./%{name} --help

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE.txt
%{_bindir}/%{name}

%changelog
* Tue Aug 29 2023 Lubos Kocman <lubos.kocman@suse.com>
- Adjust license to cover also redistributed vendor/github.com/* files
* Sat Aug 12 2023 jkowalczyk@suse.com
- Update to version 0.6.0:
  * Variables and substitutions are implemented. See docs. #1473
  * Configure timeout value with D2_TIMEOUT env var #1392
  * Scale renders and disable fit to screen with --scale flag #1413
  * null keyword can be used to un-declare. See docs #1446
  * Develop multi-board diagrams in watch mode (links to layers/scenarios/steps work in --watch) #1503
  * Glob patterns have been implemented. See docs. #1479
  * Display version on CLI help invocation #1400
  * Improved readability of connection labels when they overlap another connection #447
  * Error message when shape is given a composite #1415
  * Improved rendering and text measurement for code shapes #1425
  * The autoformatter moves board declarations to the bottom of its scope #1424
  * All font styles in sketch mode use a consistent font-family #1463
  * Tooltip and link icons are positioned on shape border #1466
  * Tooltip and link icons are always rendered over shapes #1467
  * Boards with no objects are considered folders #1504
  * DEBUG environment variable ignored if set incorrectly #1505
  * Fixes edge case in compiler using dots in quotes #1401
  * Fixes grid label font size for TALA #1412
  * Fixes person shape label positioning with multiple or 3d #1478
- _service tar_scm disable changesgenerate. Upstream uses small
  incremental commits and the automated changelog is overly long.
  Use GitHub release summary instead.
* Sat Jun 10 2023 jkowalczyk@suse.com
- Update to version 0.5.1:
  * d2ir: Fix for windows
* Sat Jun 10 2023 jkowalczyk@suse.com
- Update to version 0.5.0:
  * D2 files have the ability to import from other D2 files #1371
  * sql_table alternatively takes an array of constraints instead of being limited to a single one #1245
  * Use shape-specific sizing for grid containers #1294
  * Grid diagrams support nested shapes or grid diagrams #1309
  * grid-gap, vertical-gap, and horizontal-gap apply to padding on grid diagrams #1309
  * Watch mode browser uses an error favicon to easily indicate compiler errors #1240
  * Grid layout performance improved when there are many similarly sized shapes #1315
  * Connections and labels are adjusted for shapes with 3d or multiple #1340
  * Constraints in sql_table render even if they have no matching abbreviation #1372
  * Constraints in sql_table sheds their excessive letter-spacing and is padded from the end consistently #1372
  * Duplicate image URLs in icons are only fetched once #1373
  * In watch mode, images are cached by default across compiles. Can be disabled with flag --img-cache=0. #1373
  * Common invalid array separator , usage in class arrays returns a helpful error message #1376
  * Invalid constraint usage is met with an error message, preventing a common mistake of omitting shape: sql_table #1379
  * Connections no longer obscure outside labels #1381
  * Container connections in dagre are more balanced #1384
  * Connections that go through shape labels are now masked translucently #1383
  * Shadow is no longer cut off when --pad is 0. Thank you @LeonardsonCC ! #1326
  * Fixes grid layout overwriting label placements for nested objects #1345
  * Fixes fonts not rendering correctly on certain platforms #1356
  * Fixes folders not rendering in animations (--animate-interval) #1357
  * Fixes panic using reserved keywords as containers #1358
  * When multiple classes are change different attributes of arrowheads, all are applied instead of only the last one #1362
  * Prevent empty block strings #1364
  * Fixes dagre mis-aligning a nested shape's connection #1370
  * Fixes a bug in grids sometimes putting a shape on the next row/column #1380
  * @xyz is now reserved as a pattern for imports
* Tue May  2 2023 jkowalczyk@suse.com
- Update to version 0.4.2:
  * update get point at distance
  * fix reparsing flags
  * add logseq plugin
  * add md block info
  * fix elk issue when container named root
  * add d2sketch in ci
  * fix e2e profile passing args
  * fast attempt with debt balancing + skip bad rows
  * add maximum attempts
  * improve grid expand evenly
  * search for white index
  * fix gif pallete
  * add profiling for e2e tests
  * implement arrays for classes
  * add more detailed error msg
  * account for non-orthogonal connection segments
  * arrowhead refactor
  * fix generate unique number id
  * model_order cycle breaking elk
  * fix elk self loop spacing
  * d2oracle: don't modify classes
  * Update japan.d2
  * enforce min size for text shapes
  * remove border-radius percent tests, add border-radius pill (with a big value) test
  * feat: revert percentage border-radius. Accept higher border-radius value and limit it to half of the smaller shape side to be rendered as a pill
  * feat: check border-radius value value before checking its decimals. New rx and ry compute method.
  * feat: add possiblity to set shape border-radius with percentage value
* Tue Apr 18 2023 jkowalczyk@suse.com
- Update to version 0.4.1:
  * [ci-force] add japan example
  * [ci-base] add d2 pptx example
  * remove d2graph edge.MinWidth MinHeight
  * adjust label positioning for arrowhead
  * update bounding box for arrowhead labels
  * position arrowhead labels
  * render with arrowhead dimensions
  * set arrowhead label dimensions
  * pptx board path
  * refactor boardType
  * refactor ppt
  * remove import
  * show message while generating gif
  * navbar on pptx
  * add example
  * add constants
  * navbar on pdfs
  * Update lib/xgif/xgif.go
  * export root
  * package docs
  * export gifs
  * Fixing typos
  * refactor d2graph.Attributes
  * relative paths
  * refactor LabelWidth and LabelHeight to LabelDimensions
  * convert png boards to gif
  * Update generate_png.js
  * add exportExtension
  * add dark terrastruct flagship theme
  * e2etests: Add ent2d2 test case
  * don't increase font size for md text if container
  * update markdown text measurement and rendering to use font-size
  * rename to horizontal-gap and vertical-gap
  * fix grid panic with insuffient objects
  * if storing int and casting float64 each use
  * set scale when generating png
  * use grid-gap values for layout
  * add grid-gap keywords
  * handdrawn semibold
  * custom semibold font option
  * using semibold
  * add SourceCodePro-Semibold font
  * measure with semibold
  * use semibold font instead of font-weight: 600
  * setting up semibold font
  * add SourceSansPro-Semibold font
  * support multiboard rendering in e2e tests
  * changelog and ci
  * return svg
  * move to a single file
  * generate files from templates
  * fix layout of grid in constant near
  * move xml to templates
  * fix links in keynote
  * [ci-force] update contributing
  * add links to pptx
  * fix urls in changelogs
  * fix image resizing
  * minor fixes for MS PowerPoint
  * fix image size
  * rename and docs
  * update title
  * slide title
  * fix size and position
  * add pptx export
  * base ppt export
* Sun Apr  9 2023 jkowalczyk@suse.com
- Initial package version 0.4.0:
  * update link to tree-sitter grammar
  * add text-transform as keyword
  * fix watch mode
  * Add `text-transform` attribute to the `style` block
  * fix solo near
  * markdown class has to have diagramHash targeting
  * Lifeline should inherit the stroke style from the actor
  * fix empty layer
  * fix: attach objects of tempGraph
  * Add d2-filter as community plugin
  * update keywords rows -> grid-rows
  * new method for placing nodes across rows
  * fix inheritence bug
  * rename to grid diagram
  * validate descendants
  * layout evenly with rows and columns
  * center container if growing to fit label
  * validate edges
  * add padding between dagre labels
  * fixing rows creation
  * finish column logic
  * more dynamic grid sizing according to node sizes
  * evenly size grid nodes
  * values must be positive
  * layout with grids
  * Truncate to 32-bit precision to avoid floating-point arithmetic divergence between platforms
  * docs(readme): add golang queue library as example.
  * chore: feature description doc
  * fixes #1104
  * namespace transitions
  * fix builds on 32bit
  * have watch mode parse svg message correctly
  * fix: find outer near contaienr
  * fix: validation for near obj connect to outside
  * fix: a clean spilit for temp graph
  * d2parser: Fix #322
  * fix: validateNear outside connection
  * fix: nil labelPosition
  * fix: calc labelPosition
  * fix: delete redundant file
  * fix: use method instead of attribute
  * fix: delete redundant variable
  * fix: delete redundant return value
  * fix: ignore objects inside near container when calc boundingBox
  * fix: calc labelDimension
  * fix: integrate logic of construct sub graph inside WithoutConstantNears
  * fix: add validation for near connectioins
  * fix: compile_test testcase
  * fix: revert near_bad_connected compile_test
  * fix: delete redundant testcases
  * feat: descendants now is allowed for container with near attribute
